require 'spec_helper'

RSpec.describe PixivApi::Authentication do
  stub_pixiv_api_configuration

  let(:initialized) { described_class.new(id: id, password: password) }
  let(:id) { 'gami' }
  let(:password) { 'password' }

  shared_examples_for 'a token response' do
    it 'contains tokens' do
      expect(authentication.body['access_token']).to_not be_nil
      expect(authentication.body['refresh_token']).to_not be_nil
      expect(authentication.body['expires_in']).to_not be_nil
      expect(authentication.body['scope']).to_not be_nil
    end
  end

  describe '#initialize' do
    xcontext 'not stubbed request' do
      subject(:authentication) do
        vcr_turned_off! do
          initialized
        end
      end
      let(:password) { "Write gami's password here" } # DO NOT commit this line.

      it_behaves_like 'a token response'
    end

    context 'stubbed request' do
      subject(:authentication) do
        cassette cassette_path do
          initialized
        end
      end

      context 'when fail to authenticate user' do
        let(:cassette_path) { 'authentication_failure' }
        it { expect { authentication }.to raise_error(described_class::InvalidAuthError) }
      end

      context 'when authenticated user was successfully' do
        let(:cassette_path) { 'authentication_success' }
        it_behaves_like 'a token response'
      end
    end
  end

  describe '#to_client' do
    subject(:authentication) do
      cassette('authentication_success') { initialized }.to_client
    end

    it { is_expected.to be_a(PixivApi::Client) }
  end
end
