require 'spec_helper'

RSpec.describe PixivApi::Configuration do
  let(:configuration) { described_class.new }

  describe '#require_keys!' do
    subject do
      -> { configuration.require_keys! }
    end

    context 'when missing required keys' do
      it { is_expected.to raise_error(described_class::MissingConfigurationError) }
    end

    context 'when configuration contains required keys' do
      before do
        %i(client_id client_secret site authorize_url token_url).each do |key|
          configuration[key] = true
        end
      end

      it { is_expected.to_not raise_error }
    end
  end

  describe '#[]' do
    subject do
      -> { configuration[key] = true }
    end

    context 'given unknown key' do
      let(:key) { :unknown }
      it { is_expected.to raise_error(described_class::InvalidKeyError) }
    end

    context 'given known key' do
      let(:key) { :client_id }
      it { is_expected.to_not raise_error }
    end
  end
end
