require 'spec_helper'

RSpec.describe PixivApi::Request::FavoriteUsers do
  stub_pixiv_api_client
  let(:user_id) { 341433 }

  describe '#favorite_users' do
    subject do
      cassette 'favorite_users_success' do
        client.favorite_users
      end
    end

    it 'builds array of PixivApiResponse::User' do
      is_expected.to all(be_a(PixivApi::Response::User))
    end

    it_behaves_like 'contained pagination'
  end

  describe '#delete_favorite_users' do
    subject do
      cassette cassettle_path do
        client.delete_favorite_users(user_ids: [user_id])
      end
    end

    context 'when deleted favorite user was successfully' do
      let(:cassettle_path) { 'delete_favorite_users_success' }

      it 'builds array of PixivApiResponse::Action' do
        is_expected.to be_a(PixivApi::Response::Action)
        expect(subject).to be_success
      end
    end
  end

  describe '#favorite_user' do
    subject do
      cassette 'favorite_user_success' do
        client.favorite_user(user_id: user_id, publicity: 'public')
      end
    end

    it { is_expected.to be_a(PixivApi::Response::Action) }
  end
end
