require 'spec_helper'

RSpec.describe PixivApi::Request::Signup do
  stub_pixiv_api_client

  let(:uuid) { 'cc6fde40b5bb9b570e8a2d317881b1eb' }
  let(:mail_address) { 'yoshimin@pixiv.com' }
  let(:code) { '6774' }

  describe '#signup_validation_send_mail' do
    subject do
      cassette('signup_validation_send_mail') do
        client.signup_validation_send_mail(params: { uuid: uuid, mail_address: mail_address })
      end
    end


    it { is_expected.to be_a(PixivApi::Response::SignupValidationResult) }
  end

  describe '#signup_send_mail' do
    subject do
      cassette('signup_send_mail') do
        client.signup_send_mail(params: { uuid: uuid, mail_address: mail_address })
      end
    end

    it { is_expected.to be_a(PixivApi::Response::SignupValidationResult) }
  end

  describe '#signup_validation_check_code' do
    subject do
      cassette(cassette_file) do
        client.signup_validation_check_code(params: { uuid: uuid, mail_address: mail_address, code: code })
      end
    end

    context 'when code is valid' do
      let(:cassette_file) { 'signup_validation_check_code' }

      it { is_expected.to be_a(PixivApi::Response::SignupValidationResult) }
    end

    context 'when code is invalid' do
      let(:cassette_file) { 'signup_validation_check_code_invalid' }

      let(:code) { '9999' }

      it { expect(-> { subject }).to raise_error(OAuth2::Error) }

    end
  end

  describe '#signup_validation' do
    subject do
      cassette('signup_validation') do
        client.signup_validation(params: { uuid: uuid, mail_address: mail_address, code: code })
      end
    end

    it { is_expected.to be_a(PixivApi::Response::SignupValidationResult) }
  end

  describe '#signup' do
    subject do
      cassette('signup') do
        client.signup(params: { uuid: uuid, mail_address: mail_address, code: code })
      end
    end

    it { is_expected.to be_a(PixivApi::Response::SignupValidationResult) }

    it { expect(subject.is_valid).to eq(false) }
    it { expect(subject.pixiv_id).to_not be_nil }
  end
end
